#version 430 core
struct Material {
    sampler2D diffuse;
    vec3 specular;
    float shininess;
};

struct Light {  
    vec3 ambient;
    vec3 diffuse;
    vec3 specular;
};

in vec3 worldNormal;
in vec2 fragmentUV;
in vec3 fragPos;

layout (location = 0) out vec4 fragColor;

uniform sampler2D color_texture;
uniform vec3 viewPos;
uniform vec3 lightPos; 
uniform vec3 lightColor;
uniform Material material;
uniform Light light;

void main()
{
	/*float ambientStrength = 0.5f;
    vec3 ambient = ambientStrength * lightColor;   
	vec3 norm = normalize(worldNormal);
    vec3 lightDir = normalize(lightPos - fragPos);
	float diff = max(dot(norm, lightDir), 0.0);
    vec3 diffuse = diff * lightColor;
	vec3 textureColor = texture(color_texture, fragmentUV).rgb;
	vec3 result = (ambient + diffuse) * textureColor;
	fragColor = vec4(result, 1.0);*/

	vec2 TexCoords = fragmentUV;

	// Ambient
	vec3 ambient = light.ambient * vec3(texture(material.diffuse, TexCoords));
  	
    // Diffuse 
    vec3 norm = normalize(worldNormal);
    vec3 lightDir = normalize(lightPos - fragPos);
    float diff = max(dot(norm, lightDir), 0.0);
	vec3 diffuse = light.diffuse * diff * vec3(texture(material.diffuse, TexCoords)); 
    
    // Specular
    vec3 viewDir = normalize(viewPos - fragPos);
    vec3 reflectDir = reflect(-lightDir, norm);  
    float spec = pow(max(dot(viewDir, reflectDir), 0.0), material.shininess);
    vec3 specular = light.specular * (spec * material.specular);  
        
    vec3 result = ambient + diffuse + specular;
    fragColor = vec4(result, 1.0f);


	//-------------------------------------------------
	//Fragment Shader for objects without materials
	//-------------------------------------------------
	/*// Ambient
    vec3 ambient = lightColor * material.diffuse;
  	
    // Diffuse 
    vec3 norm = normalize(worldNormal);
    vec3 lightDir = normalize(lightPos - fragPos);
    float diff = max(dot(norm, lightDir), 0.0);
    vec3 diffuse = lightColor * (diff * material.diffuse);
    
    // Specular
    vec3 viewDir = normalize(viewPos - fragPos);
    vec3 reflectDir = reflect(-lightDir, norm);  
    float spec = pow(max(dot(viewDir, reflectDir), 0.0), material.shininess);
    vec3 specular = lightColor * (spec * material.specular);  
        
    vec3 result = ambient + diffuse + specular;
    fragColor = vec4(result, 1.0f);*/
}